/* Sample client program using libargus. */

#include <stdio.h>
#include <stdlib.h>

#include <libargus.h>

/* TODO:
 *
 * > Proper error handling.
 *
 * > Ncurses mode:
 *   - Multicolumn display.
 *   - SIGWINCH.
 *   - Colors. :^)
 *   - Minimum and maximum values.
 *   - Jitter factor.  (Running average of differential?)
 *   - User input, such as reset, quit, and remove sensor.
 *   - Activity meter, based on time of last update.
 *
 * > Command-line mode:
 *   - Parameter to specify name of argusd socket.
 *   - Option to suppress sensor names.
 *   - List of sensor names on command line.
 *
 */

int main(void)
{
    int i, len, num_sensors, ret;
    int label_width = 0;
    argus_t* ctx;
    char** sensors;
    cb_state_t s;

    /* Connect to the argusd server. */
    ret = argus_connect(&ctx, "/tmp/argusd");

    /* Get a list of sensors connected to argusd. */
    ret = argus_sensors(ctx, &sensors);
    if (ret < 0) {
        return EXIT_FAILURE;
    } else if (ret == 0) {
        fprintf(stderr, "No sensors found; aborting.\n");
        return EXIT_FAILURE;
    }
    num_sensors = ret;

    /* Determine the width of the longest sensor name. */
    for (i = 0; i < num_sensors; ++i) {
        len = strlen(sensors[i]);
        if (label_width < len) label_width = len;
    }

    /* Monitor all sensors. */
    ret = argus_listen(ctx, sensors);

    /* Get current values for sensors. */
    ret = argus_read(ctx);

    /* Display current values for all sensors. */
    for (i = 0; i < num_sensors; ++i) {
        printf("%*s : %3d\n", label_width, sensors[i], ctx->sensor_values[i]);
    }

    /* Disconnect from the argusd server. */
    ret = argus_disconnect(ctx);

    /* Cleanup. */
    free(sensors);

    return EXIT_SUCCESS;
}

/* vim: set ts=4 sts=4 sw=4 tw=80 et: */
