/* lib/error.h
 *
 * Error handling junk.
 *
 * Copyright (C) 2003, 2004
 * Zorica Majdov <zmajdov@virtuoso.com>
 * Andy Goth     <unununium@openverse.com>
 *
 * This code is available under the GNU General Public License; see COPYING. */

#ifndef SEEN_LIB_ERROR_H
#define SEEN_LIB_ERROR_H

/* Preproccessor definitions. */
#define E_OK       0   /* Success.                         */
#define E_ERROR    1   /* Generic error.                   */
#define E_ERRNO    2   /* libc error; check errno.         */
#define E_INVAL    3   /* Bad param or param out of range. */
#define E_MEMORY   4   /* Out of memory.                   */
#define E_SEARCH   5   /* Search failure.                  */
#define E_ASSERT   6   /* Error in program.                */
#define E_COUNT    7   /* (Total number of error codes.)   */
#define E_USER     100 /* First custom error code.         */

/* List of short error names. */
extern const char* error_name[E_COUNT];

/* List of short error descriptions. */
extern const char* error_desc[E_COUNT];

/* Initializes error printing.  Sets the program name to 'prog_name'. */
extern int error_init(const char* prog_name);

/* Prints the error associated with 'e'.  Also prints 'func' if supplied.  If
 * 'mesg' is non-NULL, it is printed in place of 'e'. */
extern int error_print(int e, const char* func, const char* mesg, ...);

/* Calls error_print() and terminates with an error code of abs('e'). */
extern int error_bail(int e, const char* func, const char* mesg, ...);

#endif

/* ======================================================================== */

/* vim: set ts=4 sts=4 sw=4 tw=80 et: */
/* EOF */
