/* ss-core/main.c
 *
 * Entry point of Smartshelf core program.
 *
 * Copyright (C) 2003, 2004
 * Zorica Majdov <zmajdov@virtuoso.com>
 * Andy Goth     <unununium@openverse.com>
 *
 * This code is available under the GNU General Public License; see COPYING. */

#include <stdlib.h>
#include <termios.h>

#include "ss-core/com/serial.h"
#include "ss-core/com/stdinout.h"
#include "ss-core/dev/pressure.h"
#include "ss-core/dev/rfid.h"
#include "ss-core/lib/device.h"
#include "ss-core/lib/error.h"
#include "ss-core/lib/misc.h"

/* Entry point, main event loop, and cleanup. */
int main(int argc, char** argv)
{
    int ret;
    device_t* rfid, *pressure, *client;

    /* Initialize some junk. */
    error_init("smartshelf");
    device_init();

    /* Initialize the RFID tag reader. */
    device_new(&rfid, "RFID", "/dev/ttyS1");
    serial_open(rfid, CS8, 0, PARENB, B38400, 0, IXOFF);
    rfid_open(rfid);

    /* Initialize the pressure sensor. */
    device_new(&pressure, "pressure", "/dev/ttyS0");
    /* serial_open(pressure, CS8, 0, 0, B9600, 0, CRTSCTS); */
    argus_open(pressure);
    pressure_open(pressure);

    /* Initialize the client connection. */
    device_new(&client, "client", "[stdio]");
    stdinout_open(client);
    client_open(client);

    /* Main loop. */
    device_event_loop();

    /* Shutdown. */
    device_del(rfid);
    device_del(pressure);
    /* device_del(client); */
    device_cleanup();

    return EXIT_SUCCESS;
}

/* vim: set ts=4 sts=4 sw=4 tw=80 et: */
/* EOF */
